@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for sdb service client paginators.
 
@@ -18,16 +19,16 @@ Usage::
     select_paginator: SelectPaginator = client.get_paginator("select")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_sdb.type_defs import (
     ListDomainsResultTypeDef,
     PaginatorConfigTypeDef,
     SelectResultTypeDef,
 )
 
-
 __all__ = ("ListDomainsPaginator", "SelectPaginator")
 
 
